# Script computeRegionWiseIFRs.R, to compute Infection Fatality Rates for all regions of France.

# this data comes from the last column of Table 1 in Verity et al., 2020
age_IFR <- read.table("IFR_China.csv", h=T, sep=";")


# French CFR coming from Flaxman et al.: 0.011526, whereas for China it is: 0.0138
cfr_ratio = 0.011526/0.0138

# Rescaling the age_IFR variables to obtain French IFRs, i.e. age_IFR_fr:
age_IFR_fr = cfr_ratio * age_IFR$ifr

# Now we want to obtain region-wise IFRs
# We get the region-wise demographies
demog <- read.table("estim_pop_nreg_by_decade_2020.csv", h=T, sep=";")

# We compute a weighted sum to get region-wise IFRs
demog$IFR = apply(demog[,2:10],1,function(z)sum(z*age_IFR_fr[-1])/sum(z))

# We save the resulting table in the folder data
write.table(x=demog, file="region_wise_IFR.csv", quote=F, sep=";", row.names=F)
