# Attempt at using the Flaxman et al. model on French regions.

 - [Flaxman et al. original implementation](https://github.com/ImperialCollegeLondon/covid19model)
 - [Updated model details](https://github.com/ImperialCollegeLondon/covid19model/blob/master/Technical_description_of_Imperial_COVID_19_Model.pdf)


This is an adaptation of the Flaxman et al. model of the COVID-19 epidemic, 
modified to consider french regions instead of countries.


# Getting started 

Due to R's policy regarding working directories, it is recommended that any script be launched from project root directory.

## Requirements

- R packages
  - rstan
  - tidyverse >= 1.3.0
  - lubridate

- R packages (only required for plotting results)
  - ggplot2 >= 3.3.0
  - scales
  - cowplot
  - bayesplot
  - ggpubr
  - matrixStats


Some Debian packages were also required to enable compilation of some R packages (such as `rstan`)
above : 
 - liblapack-dev 
 - libblas-dev
 - libeigen3-dev

## Fetching the data
Use make:
```bash
make opencovid
make -B results/merge_spf_opencovid_agences_regionales_sante/mergedDataReadyToAnalyze.csv
```

## Running the model

```bash
# Debug mode : iter = 40
Rscript scripts/region_sparse.R [options] <path/to/model>
```
- Output is saved in `results/` as a `.Rdata` file containing:
  - `out` : sampled parameter values resulting from the estimation process by STAN
  - `grouped_dataset` : the dataset used to fit the model
  - `stan_data` : an R list object representation of `grouped_dataset`. This is the input for STAN.

Refer to the Makefile for different exemples of model runs.

## Analysis

`/scripts` directory contains the code used to analyse both data and model outputs, including generating figures. 