// Adapted from original model "base.stan" by Flaxman et al
// https://github.com/ImperialCollegeLondon/covid19model


data {
  int <lower=1> M; // number of regions
  int <lower=1> N0; // number of days for which to impute infections
  int <lower=1> N2; // days of observed data + # of days to forecast
  int <lower=1> N_obs; // total number of observations
  
  int <lower=1, upper=M> mm[N_obs];
  int <lower=1, upper=N2> nn[N_obs];
    
  matrix[N2, M] f; // h * s
  matrix[N2, M] lockdown; // lockdown

  real SI[N2]; // fixed pre-calculated SI using empirical data from Neil

  real<lower=0> y[M];
  real<lower=0> phi;
  real <lower=0> ifr_noise[M];

  matrix[N2, M] Rt_adj;
}
  
generated quantities {
  matrix[N2, M] prediction = rep_matrix(0,N2,M);
  matrix[N2, M] E_deaths  = rep_matrix(0,N2,M);
  matrix[N2, M] deaths  = rep_matrix(0,N2,M);
  {
    for (m in 1:M){
      prediction[1:N0,m] = rep_vector(y[m],N0); // learn the number of cases in the first N0 days
      
      for (i in (N0+1):N2) {
        real convolution=0;
        for(j in 1:(i-1)) {
          convolution += prediction[j, m] * SI[i-j];
        }
        prediction[i, m] = Rt_adj[i,m] * convolution;
      }
      
      E_deaths[1, m]= 1e-15 * prediction[1,m];
      for (i in 2:N2){
        for(j in 1:(i-1)){
          E_deaths[i,m] += prediction[j,m] * f[i-j,m] * ifr_noise[m];
        }
      }
      for (i in 1:N2){
        deaths[i,m] = neg_binomial_2_rng(E_deaths[i,m], phi);
      }
    }
  }
}
