// Adapted from original model "base.stan" by Flaxman et al
// https://github.com/ImperialCollegeLondon/covid19model


data {
  int <lower=1> M; // number of regions
  int <lower=1> N0; // number of days for which to impute infections
  int <lower=1> N2; // days of observed data + # of days to forecast
  int <lower=1> N_obs; // total number of observations
  
  int <lower=1, upper=M> mm[N_obs];
  int <lower=1, upper=N2> nn[N_obs];
  
  matrix[N2, M] f; // h * s
  matrix[N2, M] lockdown; // lockdown
  matrix[N2, M] elections; // lockdown

  real SI[N2]; // fixed pre-calculated SI using empirical data from Neil

  real<lower=0> y[M];
  real<lower=0> phi;
  real <lower=0> ifr_noise[M];
  real mu[M];
  real alpha;
  int pop[M];
  real Rt_mod;
}
  
generated quantities {
  matrix[N2, M] prediction = rep_matrix(0,N2,M);
  matrix[N2, M] E_deaths  = rep_matrix(0,N2,M);
  matrix[N2, M] deaths  = rep_matrix(0,N2,M);
  matrix[N2, M] Rt = rep_matrix(0,N2,M);
  matrix[N2, M] Rt_adj = Rt;
  {
    matrix[N2,M] cumm_sum = rep_matrix(0,N2,M);
    for (m in 1:M){
      for (i in 2:N0){
        cumm_sum[i,m] = cumm_sum[i-1,m] + y[m]; 
      }
      prediction[1:N0,m] = rep_vector(y[m],N0); // learn the number of cases in the first N0 days
      
      Rt[,m] = mu[m] * exp(
        lockdown[,m] * (-alpha)
        // covariate4[,m] * (-alpha[4]) + 
        // covariate5[,m] * (-alpha[5]) + 
        // covariate6[,m] * (-alpha[6]) 
        );
      
      Rt_adj[1:N0,m] = Rt[1:N0,m];
      
      for (i in (N0+1):N2) {
        real convolution=0;
        for(j in 1:(i-1)) {
          convolution += prediction[j, m] * SI[i-j];
        }
        cumm_sum[i,m] = cumm_sum[i-1,m] + prediction[i-1,m];
        // adjust Rt for population saturation effect
        Rt_adj[i,m] = ((pop[m]-cumm_sum[i,m]) / pop[m]) * Rt[i,m] * (elections[i,m] == 1. ? Rt_mod : 1);
        prediction[i, m] = Rt_adj[i,m] * convolution;
      }
      
      E_deaths[1, m]= 1e-15 * prediction[1,m];
      for (i in 2:N2){
        for(j in 1:(i-1)){
          E_deaths[i,m] += prediction[j,m] * f[i-j,m] * ifr_noise[m];
        }
      }
      for (i in 1:N2){
        deaths[i,m] = neg_binomial_2_rng(E_deaths[i,m], phi);
      }
    }
  }
}
