suppressPackageStartupMessages({
  library(tidyverse)
  source("scripts/data_preproc/preproc_functions.R")
})

args <- commandArgs(trailingOnly = TRUE)
spf_input <- args[1]
output_dir <- args[2]

if(is.null(output_dir))
  output_dir = "results/SPF"

dir.create(output_dir, recursive = T, showWarnings = F)

# ------------------------------------------------------------------------------

dpt_reg_equiv <- read.csv(
  "https://www.data.gouv.fr/fr/datasets/r/987227fb-dcb2-429e-96af-8979f97c9c84",
  col.names=c("dep", "dep_name", "reg"),
  stringsAsFactors = F
) %>%
  mutate(reg=if_else(str_length(dep) > 2, "outre-mer", rename_region(reg, sep='-')) )


spf_data <- read.csv(spf_input, sep=";", stringsAsFactors = F) %>%
  rename_at(vars(starts_with("incid_")), ~str_remove(., "incid_")) %>%
  left_join(dpt_reg_equiv, by="dep") %>%
  mutate(reg)

dep_out_file <- file.path(output_dir, "dptData.csv")
sprintf("Writing departement dataset @ %s", dep_out_file) %>% message()
write.table(spf_data, dep_out_file, row.names=F, sep=";")

reg_data <- spf_data %>%
  select(-starts_with("dep")) %>%
  group_by(reg, jour) %>%
  summarise_all(sum)

reg_out_file <- file.path(output_dir, "regData.csv")
sprintf("Writing region dataset @ %s", reg_out_file) %>% message()
write.table(reg_data, reg_out_file, row.names=F, sep=";")  
  
