import pandas as pd

# Input and output:
data_spf = pd.read_csv("results/SPF/regData.csv",
                       sep=";", header=0, parse_dates=[1])
data_open = pd.read_csv(
    "results/opencovid_agences_regionales_sante/data_reg_outremer_diff.csv",
    sep=";", header=0, parse_dates=[2])
output_csv_table = "results/merge_spf_opencovid_agences_regionales_sante/mergedDataReadyToAnalyze.csv"

# QC:
# data_spf.columns
# data_spf.describe(include='all')

# data_open.columns
# data_open.describe(include='all')

# Let's remove the sex information in the Santé Publique France data
# data_spf_nosex = data_spf[data_spf.sexe == 0]

# Let's drop useless columns
# data_spf_nosex = data_spf_nosex.drop(['sexe'], axis='columns')
data_spf_nosex_wide = data_spf.pivot(index='jour', columns='reg', values='dc')

data_open = data_open.drop(['dep', 'sexe'], axis='columns')
data_open_wide = data_open.pivot(index='jour', columns='reg', values='dc')\
    .drop(['988', 'sante-publique-france', 'ministere-sante'], axis='columns')

merged = pd.merge(data_spf_nosex_wide, data_open_wide,
                  on=['jour'], suffixes=["_spf", "_open"], how='outer')

# Creating a concatenated dataset
data_concatenated = data_open_wide.copy()

idx = pd.date_range(merged.index.min(), merged.index.max())
data_concatenated = data_concatenated.reindex(idx, fill_value=0)

for reg in data_spf_nosex_wide.columns:
    for day in merged.index:
        print(day)
        value = "NA"
        try:
            value = data_spf_nosex_wide[reg][day]
        except KeyError as err:
            print("Error date not found: " + str(day) + " : {0}".format(err))
        print(value)
        if value != "NA":
            data_concatenated[reg][day] = value
            print("SOOOO : ")
            print(data_concatenated[reg][day])

data_concatenated.to_csv(output_csv_table, index_label="jour")
