library(pbapply)
pboptions(type="timer")

as_sample_df <- function(mcmc_matrix, varname){
  mcmc_matrix %>% 
    as.data.frame() %>%
    mutate(sample_id = 1:n()) %>%
    pivot_longer(-sample_id, names_to="day_id", values_to = varname) %>%
    mutate(day_id = str_remove(day_id, "V") %>% as.integer())
}

extract_mixture_dataset <- function(dataset, stanfit, categories=c(1,2)){
  phi <- stanfit$phi
  region_ids <- unique(dataset$region_id)
  region_ids %>% 
    pblapply(
      cl=parallel::detectCores() - 1,
      function(region_id){
        categories %>% lapply(function(category){
          as_sample_df(stanfit$E_deaths[,category,,region_id], "deaths_mean") %>%
            arrange(day_id) %>%
            mutate(
              new_cases = as.vector(stanfit$prediction[,category,,region_id]),
              Rt = as.vector(stanfit$Rt_adj[,category,,region_id]),
              theta = rep(stanfit$theta[,category], max(day_id)),
              alpha = rep(stanfit$alpha[,category], max(day_id)),
              R0 = rep(stanfit$mu[,region_id], max(day_id)),
              region_id,
              category
            )
        }) %>% bind_rows()
      }) %>% bind_rows() %>%
    left_join(dataset, by=c("region_id", "day_id")) %>%
    fill(region, .direction="down") %>%
    mutate(
      likelihood = dnbinom(deaths, size=phi[sample_id], mu=deaths_mean, log=T),
      deaths_pred = rnbinom(deaths_mean, size=phi[sample_id], mu=deaths_mean)
    ) %>%
    group_by(region, region_id) %>%
    mutate(date = min(date, na.rm=T) + day_id - 1) %>%
    group_by(category, sample_id, region, region_id) %>%
    arrange(date) %>%
    mutate(
      total_deaths = cumsum(deaths_pred),
      total_cases = cumsum(new_cases)
    )
}
