suppressPackageStartupMessages({
  library(tidyverse)
  library(lubridate)
  library(pbapply)
  library(data.table)
  library(optparse)
  
  source("scripts/mixture_analysis/functions.R")
})

parser <- OptionParser() %>%
  add_option(c("-i", "--input"),
    default="results/region-sparse-oneintervention-mixture-gamma-prior-latest.Rdata",
    action="store",
    help="Stan output file (.Rdata)") %>%
  add_option(c("-o", "--output"),
    default = "results/mixture_decoded_posterior.csv",
    action="store",
    help="Decoded fit output file")


cmdoptions <- parse_args(parser,
  args = commandArgs(trailingOnly = TRUE),
  positional_arguments = TRUE)

INPUT <- cmdoptions$options$input
OUTPUT <- cmdoptions$options$output

pboptions(type="timer")

LOCKDOWN <- ymd("2020-03-17")
LOCKDOWN_END <- ymd("2020-05-11")

sprintf("Loading %s", INPUT) %>% message()
loaded_data <- new.env()
load(INPUT, v=T, envir=loaded_data)
dataset <- loaded_data$grouped_dataset %>% select(-t)
stanfit <- loaded_data$out

(mixture <- extract_mixture_dataset(dataset, stanfit, categories=c(1,2)))

posteriors <- mixture %>%
  group_by(sample_id, region, region_id, category) %>%
  summarise(posterior=exp(log(unique(theta)) + sum(likelihood, na.rm=T)))

sample_categories <- as.data.table(posteriors)[,
  `:=`(
    sampled_category=sample(category, size=1, prob=posterior/sum(posterior)),
    prob=posterior/sum(posterior)
  ),
  by=.(region, region_id, sample_id)
  ] %>% as_tibble()

write_csv(sample_categories, "results/mixture_categories.csv")

mixture_decoded <- mixture %>% 
  inner_join(sample_categories, by=c("region", "region_id", "category", "sample_id")) %>%
  select(-likelihood, -posterior) %>%
  filter(category == sampled_category)


# mixture_decoded <-  mixture_posteriors %>%
#   group_by(region, region_id, sample_id <=1000) %>%
#   group_split() %>%
#   pblapply(cl=parallel::detectCores() - 1,
#     function(split_data){
#       as.data.table(split_data)[ ,
#         lapply(.SD, sample, size=1, prob=posterior/sum(posterior)),
#         by=.(region, region_id, day_id, date, sample_id, deaths), 
#         .SDcols=c(
#           "deaths_mean", "deaths_pred", "R0", "Rt", "alpha", "new_cases", 
#           "total_cases", "total_deaths")
#         ]
#     }) %>%
#   bind_rows()

sprintf("Saving decoded dataset @ %s", OUTPUT) %>% message()

data.table::fwrite(mixture_decoded, file=OUTPUT)
    
