suppressPackageStartupMessages({
  library(tidyverse)
  library(lubridate)
  library(ggpubr)
  source("scripts/mixture_analysis/functions.R")
})

loaded_data <- new.env()
load("results/region-sparse-oneintervention-mixture-gamma-prior-latest.Rdata", 
  v=T, envir=loaded_data)
stanfit <- loaded_data$out
stan_data <- loaded_data$stan_data
dataset <- loaded_data$grouped_dataset


theta_prior <- data.frame(prior=rbeta(100000,1,1))

theta_prior <- data.frame(theta=seq(0,1,0.01)) %>%
  mutate(density=dbeta(theta, 1, 1))
theta_posterior <- stanfit$theta %>% as.data.frame() %>% 
  set_names(c("theta1", "theta2")) %>%
  pivot_longer(cols=everything(), names_to="theta", values_to="value")

(
  plt <- ggplot(data=theta_prior) +
    geom_density(aes(theta, density, col="prior")) +
    geom_density(data=theta_posterior, aes(value, col=theta)) +
    scale_color_discrete("") +
    theme_pubr()
)

cowplot::save_plot("report/SupplementaryData/figures/theta-posterior.png", plt)
