suppressPackageStartupMessages({
  library(tidyverse)
  library(lubridate)
  library(ggpubr)
  library(data.table)
})

LOCKDOWN = ymd("2020-03-17")
LOCKDOWN_END = ymd("2020-05-11")



df <- fread(file="results/mixture_decoded_posterior.csv") %>%
  mutate(date = ymd(date)) %>%
  filter(date <= LOCKDOWN_END) %>%
  as_tibble()
  
(
  Rt_fc_plt <- df %>% 
    mutate(Rt_foldchange = exp(-alpha)) %>%
    group_by(region, region_id, sample_id) %>%
    summarise(Rt_foldchange = unique(Rt_foldchange)) %>%
    ggplot(aes(fct_rev(region))) +
    geom_violin(aes(y=Rt_foldchange)) +
    scale_x_discrete("") +
    scale_y_continuous("Rt fold-change") +
    coord_flip() +
    theme_pubr() +
    theme(plot.margin = unit(c(0.5,1,0.5,0), "cm"))
)


cowplot::save_plot("report/figures/Rt_mixture.png", Rt_fc_plt)
