suppressPackageStartupMessages({
  library(tidyverse)
  library(optparse)
  source("scripts/data_preproc/preproc_functions.R")
  source("scripts/plots/utils/utils.R")
  source("scripts/plots/three-panel/functions.R")
  invisible(Sys.setlocale("LC_ALL", locale="en_US.utf8"))
})

#---------------------------------------------------------------------------

parser <- OptionParser() %>%
  add_option(c("-i", "--input"),
    default="results/mixture_decoded_posterior.csv",
    action="store",
    help="Stan output file (.Rdata)") %>%
  add_option(c("-o", "--output"),
    default = "mixture",
    action="store",
    help="Decoded fit output file")


cmdoptions <- parse_args(parser,
  args = commandArgs(trailingOnly = TRUE),
  positional_arguments = TRUE)

INPUT <- cmdoptions$options$input
OUTPUT <- cmdoptions$options$output

LOCKDOWN_END = ymd("2020-05-11")


sprintf("Loading %s", INPUT) %>% message()
mixture_df <- data.table::fread(file = INPUT, colClasses = c(date="Date"))

# load covariates
covariates <- load_covariates("data/interventions.csv") %>%
  pivot_longer(names_to = "interv", values_to = "date", cols = everything()) %>%
  mutate(x=0)

q <- c(0.025, 0.25, 0.5, 0.75,  0.975) 
q_funs <- map(q, ~partial(quantile, probs=.x, na.rm=TRUE)) %>% 
  set_names(c("min", "min2", "med", "max2", "max"))

# start plotting
mixture_df %>%
  filter(date <= LOCKDOWN_END) %>%
  rename(
    predicted_cases=new_cases,
    mean_deaths=deaths_mean,
    predicted_deaths=deaths_pred,
    rt=Rt
  ) %>%
  select(-total_cases, -total_deaths) %>%
  pivot_longer(c(mean_deaths, predicted_deaths, predicted_cases, rt),
    names_to = "variable_name", values_to = "value")%>%
  group_by(region, region_id, date, variable_name, deaths) %>%
  summarise_at(vars(value), q_funs) %>%
  group_by(region) %>%
  group_walk(covariates, .f=function(region_data, key, covariates){
    region <- key$region
    sprintf(" + Plotting region %s", region)%>% message()
    p1 <- plot_cases(region_data, region)
    p2 <- plot_deaths(region_data)
    p3 <- plot_rt(region_data, region, covariates)
    save_plots(region, p1, p2, p3, filename=OUTPUT)
  })

message("Done")


