import pandas as pd
import unicodedata

# contents of the chiffre_clés file:
# date,granularite,maille_code,maille_nom,cas_confirmes,cas_ehpad,cas_confirmes_ehpad,cas_possibles_ehpad,deces,deces_ehpad,reanimation,hospitalises,gueris,depistes,source_nom,source_url,source_archive,source_type

# We output a file with:
# jour,auvergne-rhone-alpes,bourgogne-franche-comte,bretagne,centre-val-de-loire,corse,grand-est,hauts-de-france,ile-de-france,normandie,nouvelle-aquitaine,occitanie,outre-mer,pays-de-la-loire,provence-alpes-cote-dazur
# which contains the daily numbers of deaths

# Loading useful functions
exec(open("scripts/util_fun.py").read())

def renameDpt (dep):

    print(dep)
    if dep.startswith("0"):
        toReturn = dep[1:]
        return toReturn
    else:
        return dep

if __name__ == '__main__':
    filein = "DataFromOpenCovid/data/dist/chiffres-cles.csv"
    outfilereg = "results/opencovid_chiffres_cles/data_reg.csv"
    outfileregmerged = "results/opencovid_chiffres_cles/data_reg_merged.csv"
    outfileregdiff = "results/opencovid_chiffres_cles/data_reg_diff.csv"
    output_csv_table_for_stan ="results/opencovid_chiffres_cles/mergedDataReadyToAnalyze.csv"

    header = "\"reg\";\"dep\";\"sexe\";\"jour\";\"hosp\";\"rea\";\"rad\";\"dc\"\n"
    with open(filein, "r") as fin, open(outfilereg, "w") as fout_reg:
        print("We want a file with:" + header)
        fout_reg.write(header)
        for l in fin:
            try:
                li = l.split(",")
                if li[1]=="region":
                    fout_reg.write(li[3] + ";" + "NA" + ";" + "0;" +li[0] + ";" + li[11] +";" + li[10] +";" + li[12] +";" + li[8] + "\n")
                elif li[1]=="granularite":
                    print("Selecting fields: " + li[3] + ";" + "NA" + ";" + "0;" +li[0] + ";" + li[11] +";" + li[10] +";" + li[12] +";" + li[8] + "\n")
            except KeyError as err:
                print("ERROR with line: " + l + "and error: {0}".format(err))

    #with open(outfilereg, "w"):
    data_reg = pd.read_csv(outfilereg, sep=";", header=0, parse_dates=[3] )
    # Now we want to merge the data by region per day
    data_reg_merged = data_reg.groupby(['reg', 'jour']).sum()
    data_reg_merged.to_csv(outfileregmerged, sep=";", index=True)

    data_reg_merged = pd.read_csv(outfileregmerged, sep=";", header=0, parse_dates=[1] )

    # Compute deltas to get numbers of events per days and not totals.
    for reg in data_reg_merged["reg"].unique():
        calculate_change_in_field_given_value_in_other_field(df=data_reg_merged, field_for_computing_change="dc", indicator_field="reg", indicator_value=reg, new_field="quotidien_dc")

    data_reg_merged['dc'] = data_reg_merged['quotidien_dc']
    del(data_reg_merged['quotidien_dc'])
    data_reg_merged.to_csv(outfileregdiff, sep=";", index=False)

    # Produce the file ready to be analyzed by the Stan script
    data_open_wide = data_reg_merged.pivot(index='jour', columns='reg', values='dc')
    idx = pd.date_range(data_open_wide.index.min(), data_open_wide.index.max())
    data_concatenated = data_open_wide.reindex(idx, fill_value=0.0)
    data_concatenated.index.name="jour"
    # removing accents and spaces and uppercase letters
    cols = data_concatenated.columns.tolist()
    for i in range(len(cols)):
        s_no_accent = ''.join((c for c in unicodedata.normalize('NFD', cols[i].lower().replace(" ", "-")) if unicodedata.category(c) != 'Mn'))
        cols[i] = s_no_accent
    data_concatenated.columns = cols
    # Merging some columns into outre-mer
    # To merge: guadeloupe, guyane, la-reunion, martinique, mayotte
    data_concatenated["outre-mer"] = data_concatenated["guadeloupe"] + data_concatenated["guyane"] + data_concatenated["la-reunion"] + data_concatenated["martinique"] + data_concatenated["mayotte"]
    data_concatenated = data_concatenated.drop(["guadeloupe", "guyane", "la-reunion", "martinique", "mayotte"], axis='columns')
    data_concatenated.to_csv(output_csv_table_for_stan)
