suppressPackageStartupMessages({
  library(tidyverse)
  library(ggpubr)
  
  source("scripts/data_preproc/preproc_functions.R")
  source("scripts/plots/utils/utils.R")
  source("scripts/plots/three-panel/functions.R")
})

#---------------------------------------------------------------------------

args <- commandArgs(trailingOnly = TRUE)
filename = args[1]
# filename <- "results/region-sparse-lockdown-latest.Rdata"

# load variables : grouped_dataset, out
sprintf("LOADING : %s",filename) %>% message()
loaded_data <- new.env()
load(filename, envir=loaded_data)
stanfit <- loaded_data$out
dataset <- loaded_data$grouped_dataset

invisible(Sys.setlocale("LC_ALL", locale="en_US.utf8"))

# start plotting
plotted_data <- dataset %>% 
  group_map(make_plot_data_region, stanfit) %>%
  bind_rows() %>%
  as_tibble()

(
  plt <- plotted_data %>% 
    filter(variable_name == "predicted_deaths_csum", date >= ymd("2020-03-01")) %>%
    group_by(date) %>%
    summarise_at(vars(min, max, min2, max2, median, obs_deaths_csum), sum) %>%
    ungroup() %>%
    ggplot(aes(x=date)) +
    geom_ribbon(aes(ymin=min, ymax=max, fill="95%")) +
    geom_ribbon(aes(ymin=min2, ymax=max2, fill="50%")) +
    geom_line(aes(y=median, lty="median", col="median", lwd="median")) +
    geom_line(aes(y=obs_deaths_csum, lty="observed", col="observed", lwd="observed")) +
    scale_x_date("Date", breaks="weeks", date_labels = "%b %d") +
    scale_y_continuous("Cumulated deaths") +
    scale_fill_manual("Fit IC", values=c(alpha("deepskyblue4", 0.75), alpha("deepskyblue4", 0.45))) +
    scale_color_manual(name="", values=c("black", "orange")) +
    scale_linetype_manual(name="", values=c("solid", "dashed")) +
    scale_size_manual(name="", values=c(0.5, 1)) +
    theme_pubr() +
    theme(axis.text.x = element_text(angle=45, hjust=1))
)

output_file <- "report/figures/cumsum_deaths.png"
sprintf("Saving cumsum plot @ %s", output_file) %>% message()
cowplot::save_plot(output_file, plt, base_height = 4)



