suppressPackageStartupMessages({
  library(tidyverse)
  
  source("scripts/data_preproc/preproc_functions.R")
  source("scripts/plots/utils/utils.R")
  source("scripts/plots/three-panel/functions.R")
})

#---------------------------------------------------------------------------

args <- commandArgs(trailingOnly = TRUE)
filename = args[1]
# filename = "results/region-sparse-lockdown-latest.Rdata"

# load variables : grouped_dataset, out
sprintf("LOADING : %s",filename) %>% message()
load(filename, v=T)

invisible(Sys.setlocale("LC_ALL", locale="en_US.utf8"))

# start plotting
(
  plt <- grouped_dataset %>% 
    group_map(make_plot_data_region, out) %>%
    bind_rows() %>%
    filter(region_id %in% c(1, 6 ,8)) %>%
    plot_deaths(lockdown.legend = T) + 
    facet_wrap(~region, ncol=1, scales = "free_y") + 
    theme(
      strip.background = element_blank(),
      strip.text = element_text(hjust = 0, face = "bold", size = 12),
      panel.grid.major.x = element_line()
    )
)

cowplot::save_plot(
  "report/figures/3-regions-fit.png", plt, 
  base_aspect_ratio = 2.5/3, base_height=8)
