suppressPackageStartupMessages({
  library(tidyverse)
  library(pbapply)  
  source("scripts/data_preproc/preproc_functions.R")
  source("scripts/plots/utils/utils.R") # using make_plot_data_regions()
  source("scripts/plots/three-panel/functions.R") # using plot_deaths()
})

fr_dataset <-
  read.csv("results/merge_spf_opencovid_agences_regionales_sante/mergedDataReadyToAnalyze.csv", h=T) %>%
  prepare_french_region_dataset()

grouped_dataset <- fr_dataset %>%
  group_by(region, region_id) %>%
  group_modify(function (region_data, keys) {
    message(keys$region %>% str_to_upper())
    message(" + PADDING : ")
    region_data <- pad_region_data(region_data)
    message(" + SLICING : ")
    region_data <- slice_from_onset(region_data)
    return(region_data)
  })

# ------------------------------------------------------------------------------

make_prefix_dataset <- function(dataset, weeks, file_pattern){
  weeks %>% lapply(function(week_id){
    filename <- sprintf(file_pattern, week_id)
    loaded_data <- new.env()
    sprintf("Loading %s", filename) %>% message()
    load(filename, env=loaded_data)
    
    stanfit <- loaded_data$out
    stan_data <- loaded_data$stan_data
    
    dataset %>% 
      group_map(make_plot_data_region, stanfit) %>%
      bind_rows() %>%
      mutate(
        last_day=stan_data$last_day_observed,
        week_id=week_id)
  }) %>%
    bind_rows()
}

weeks <- c(1, 2, 4, 8) %>% rev()
file_pattern <- "results/region-sparse-lockdown-skipweek%s.Rdata"
dataset <- grouped_dataset %>% filter(region_id == 8)
plot_data <- make_prefix_dataset(dataset, weeks, file_pattern)

prefix_area_df <- plot_data %>% 
  filter(variable_name == "predicted_deaths") %>% 
  group_by(week_id,last_day) %>%
  summarise(ymax=max(max), ymin=min(min), xmin=ymd("2020-02-03"))


invisible(Sys.setlocale(locale = "en_US.utf-8"))
(
  prefix_plot <- plot_data %>%
    plot_deaths(plot.lockdown=FALSE) +
    geom_vline(
      aes(xintercept=last_day, lty="Data prefix"), 
      col="black", alpha=0.7) +
    geom_vline(
      aes(xintercept= ymd("2020-03-17"), lty="Lockdown"), 
      col="black", alpha=1) +
    geom_rect(
      data=prefix_area_df,
      mapping=aes(xmin=xmin, xmax=last_day, ymin=ymin, ymax=ymax)
    ) +
    facet_wrap(~rev(week_id), scale="free_y") +
    scale_linetype_discrete("", guide=guide_legend(ncol=1)) +
    theme(
      legend.position="top",
      legend.text = element_text(size=13),
      strip.text = element_blank())
)


cowplot::save_plot("report/figures/prefix_plot.png", prefix_plot, base_height=5, scale=0.9)
