plot_sim <- function(simulated_region_data, region.id){
  q <- c(0.025, 0.5,  0.975) %>% set_names(paste0(.*100, "%"))
  q_funs <- map(q, ~partial(quantile, probs=.x, na.rm=TRUE))
  
  simulated_region_data %>%
    mutate(Rt_mod = factor(Rt_mod)) %>%
    group_by(Rt_mod, day_id, date) %>%
    summarize_at(vars(deaths, Rt), q_funs) %>%
    ggplot() +
    geom_ribbon(
      aes(
        x=date, ymin=`deaths_2.5%`, ymax=`deaths_97.5%`, 
        group=Rt_mod, fill=Rt_mod, col=Rt_mod), 
      alpha=0.2, lty="dotted", lwd=0.3) +
    geom_line(aes(x=date, y=`deaths_50%`, group=Rt_mod, col=Rt_mod)) +
    scale_fill_discrete("Rt fold-change") +
    scale_color_discrete("Rt fold-change") +
    xlab("Day") +
    ylab("Mortality") +
    theme_pubr(base_family="sans")
}


mortality_boxplots <- function(dataset, initial_dataset){
  invisible(Sys.setlocale(locale="en_US.UTF-8"))
  
  dataset <- dataset %>% 
    ungroup() %>%
    filter(region_id %in% c(1, 6, 7,8)) %>%
    mutate(Rt_mod = factor(Rt_mod) %>% fct_rev())
  
  dataset %>% 
    filter(date > (ymd("2020-03-15") + 10)) %>%
    group_by(sim_id, region, region_id, Rt_mod) %>%
    summarise(total = sum(deaths)) %>%
    ungroup() %>%#inner_join(peak_dates) %>%
    ggplot() +
    geom_boxplot(aes(x=region, y=total,fill=Rt_mod)) +
    scale_y_continuous("Mortality") + #, breaks=seq(0, 700, 100)) +
    scale_fill_discrete("Rt fold-change") +
    scale_linetype_manual(name="", values="dashed", label="Observed quantity") +
    xlab("Region") +
    theme_pubr(base_family = "sans")
}
