suppressPackageStartupMessages({
  library(tidyverse)
  library(ggpubr)
  library(lubridate)
  
  source("scripts/plots/simulations/functions.R")
})


# Commandline options and parsing
args <- commandArgs(trailingOnly = TRUE)
filename = args[1]

# ------------------------------------------------------------------------------

invisible(Sys.setlocale(locale="en_US.UTF-8"))

loaded_data <- new.env()
load(filename, envir = loaded_data)

simulated_dataset <- loaded_data$simulated_dataset

figures.dir <- "figures/elections_simulation/"
dir.create(figures.dir, rec=T, showWarnings=F)


simulated_dataset %>% 
  group_by(region, region_id) %>%
  group_walk(figures.dir, .f = function(region_data, keys, figures.dir){
    message(keys$region)
    region <- str_replace_all(keys$region, fixed('.'), '-')
    plt <- plot_sim(region_data, keys$region_id) + ggtitle(region)
    output_file <- file.path(figures.dir, sprintf("%s.png", region))
    cowplot::save_plot(filename=output_file, plt,
      base_height = 4, base_asp = 2)
  })

