suppressPackageStartupMessages({
  library(tidyverse)
  library(ggpubr)
  library(lubridate)
  invisible(Sys.setlocale("LC_ALL", locale="en_US.utf8"))
})

LOCKDOWN <- ymd("2020-03-17")

load("results/simulated_datasets/lockdown_shift.Rdata", v=T)

simulated_dataset %>% 
  filter(lockdown_day %>% between(LOCKDOWN-7, LOCKDOWN + 7)) %>%
  group_by(lockdown_day, sim_id) %>%
  summarise(total_deaths=sum(deaths_pred)) %>%
  ungroup() %>%
  group_by(lockdown_day) %>%
  summarise(total_deaths_median=median(total_deaths)) %>%
  write_csv(path="results/lockdown_shift_medians.csv",col_names = T)


(
  boxp <- simulated_dataset %>% 
    filter(
      date <= ymd("2020-05-11"),
      lockdown_day %>% between(LOCKDOWN-7, LOCKDOWN + 7)
    ) %>%
    group_by(lockdown_day, sim_id) %>%
    summarise(total_deaths=sum(deaths_pred)) %>%
    mutate(actual = lockdown_day == LOCKDOWN) %>%
    ggplot(aes(x=lockdown_day)) +
    geom_boxplot(aes(y=total_deaths, group=lockdown_day, col=actual), lwd=0.3) +
    geom_hline(
      aes(yintercept=obs_total_deaths, lty="observed"), 
      col="orangered", lwd=0.5) +
    scale_x_date("Lockdown start", breaks="2 days", date_labels="%b %d") +
    scale_y_continuous("Total mortality") +
    scale_color_manual(NULL, 
      values=c("black", "deepskyblue4"),
      labels=c("Counterfactual", "Actual")) +
    scale_linetype_manual(NULL, values=c("dashed")) +
    theme_pubr()
)

cowplot::save_plot("report/figures/lockdown_shift.png", boxp)
