suppressPackageStartupMessages({
  library(tidyverse)
  
  source("scripts/data_preproc/preproc_functions.R")
  source("scripts/plots/utils/utils.R")
  source("scripts/plots/three-panel/functions.R")
})

#---------------------------------------------------------------------------

args <- commandArgs(trailingOnly = TRUE)
filename = args[1]
# filename = "results/region-sparse-lockdown-latest.Rdata"

# load variables : grouped_dataset, out
sprintf("LOADING : %s",filename) %>% message()
load(filename, v=T)

# load covariates
covariates <- load_covariates("data/interventions.csv") %>%
  pivot_longer(names_to = "interv", values_to = "date", cols = everything()) %>%
  mutate(x=0)

invisible(Sys.setlocale("LC_ALL", locale="en_US.utf8"))

# start plotting
plotted_data <- grouped_dataset %>% 
  group_map(make_plot_data_region, out) %>%
  bind_rows() %>%
  group_by(region) %>%
  group_walk(covariates, .f=function(region_data, key, covariates){
    region <- key$region
    sprintf(" + Plotting region %s", region)%>% message()
    p1 <- plot_cases(region_data, region)
    p2 <- plot_deaths(region_data)
    p3 <- plot_rt(region_data, region, covariates)
    out_filename <- filename %>% basename() %>% str_remove("\\.Rdata")
    save_plots(region, p1, p2, p3, filename=out_filename)
  })

message("Done")

