# mixture_extractor <- function(mcmc_out, stan_data){
#   regions <- stan_data$regions
#   phi <- stan_data$phi
#   map_dfr(1:dim(mcmc_out$E_deaths)[2], function(category){
#     mcmc_out$E_deaths[,category,,] %>% 
#       extract_sample("deaths_mean", regions) %>%
#       arrange(region, day_id) %>%
#       mutate(
#         deaths_pred = as.vector(mcmc_out$deaths[1,category,,]),
#         new_cases = as.vector(mcmc_out$prediction[1,category,,]),
#         Rt = as.vector(mcmc_out$Rt_adj[1,category,,]),
#         category=category
#       )
#   }) 
# }
library(magrittr)

mixture_simulation <- function(sample_id, data_modifier, categories=1:2){
  stan_data <- data_modifier(sample_id)
  
  N0 <- stan_data$N0
  N2 <- stan_data$N2
  SI <- stan_data$SI
  
  categories %>% 
    lapply(function(category){
      alpha <- stan_data$alpha[category]
      theta <- stan_data$theta[category]
      map2_dfr(
        stan_data$regions, dense_rank(stan_data$regions), 
        function(region, region_id){
          
          pi_f <- stan_data$f[, region_id]
          pop <- stan_data$pop[region_id]
          ifr_noise <- stan_data$ifr_noise[region_id]
          
          new_cases <- rep(stan_data$y[region_id], N0)
          cases_cumsum <- cumsum(new_cases) %>% data.table::shift(fill=0)
          
          Rt <-  stan_data$mu[region_id] * exp(stan_data$lockdown[,region_id] * (-alpha))
          Rt_adj <- Rt[1:N0]
          
          df <- data.frame(
            new_cases=new_cases,
            total_cases=cases_cumsum,
            Rt_adj=Rt_adj,
            day_id = 1:N0,
            deaths_mean = rep(NA, N0) %>% inset(1, (1e-15*new_cases[1]))
          )
          reduce(.x=2:N2, .init=df, .f=function(data, next_day){
            if(next_day <= N0){
              d <- sum(data$new_cases * rev(pi_f[data$day_id]) * ifr_noise)
              data %>% mutate(deaths_mean = inset(deaths_mean, next_day, d))
            } else {
              convolution <- sum(data$new_cases * rev(SI[data$day_id]))
              total_cases <- sum(data$new_cases)
              Rt_adj <- (pop - total_cases) / pop * Rt[next_day]
              data %>% add_row(
                Rt_adj = !!Rt_adj,
                new_cases = !!Rt_adj * convolution,
                day_id=next_day,
                total_cases=!!total_cases,
                deaths_mean = sum(data$new_cases * rev(pi_f[data$day_id]) * ifr_noise)
              )
            }
          }) %>% mutate(region=region, region_id=region_id) # region level
          
        }) %>% mutate(category=category, theta=theta) # theta level
      
    }) %>% bind_rows() %>% as_tibble() %>% mutate(sample_id=sample_id)
}
